@@ -1,15 +1,174 @@
+use 5.006;    # pragmas
 use strict;
 use warnings;
 
 package Test::File::ShareDir;
-BEGIN {
-  $Test::File::ShareDir::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Test::File::ShareDir::VERSION = '0.4.0';
-}
-
+$Test::File::ShareDir::VERSION = '1.000000';
 # ABSTRACT: Create a Fake ShareDir for your modules for testing.
+
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 
@@ -17,21 +176,21 @@ BEGIN {
 use File::ShareDir 1.00 qw();
 
 sub import {
-  my ( $class, %input_config ) = @_;
+  my ( undef, %input_config ) = @_;
 
   require Test::File::ShareDir::TempDirObject;
 
-  my $object = Test::File::ShareDir::TempDirObject->new( \%input_config );
+  my $tempdir_object = Test::File::ShareDir::TempDirObject->new( \%input_config );
 
-  for my $module ( $object->_module_names ) {
-    $object->_install_module($module);
+  for my $module ( $tempdir_object->_module_names ) {
+    $tempdir_object->_install_module($module);
   }
 
-  for my $dist ( $object->_dist_names ) {
-    $object->_install_dist($dist);
+  for my $dist ( $tempdir_object->_dist_names ) {
+    $tempdir_object->_install_dist($dist);
   }
 
-  unshift @INC, $object->_tempdir->stringify;
+  unshift @INC, $tempdir_object->_tempdir->stringify;
 
   return 1;
 }
@@ -50,7 +209,7 @@ Test::File::ShareDir - Create a Fake ShareDir for your modules for testing.
 
 =head1 VERSION
 
-version 0.4.0
+version 1.000000
 
 =head1 SYNOPSIS
 
@@ -114,7 +273,8 @@ See L<< C<Test::File::ShareDir::Module>|Test::File::ShareDir::Module >> for deta
 
 =head3 C<Test::File::ShareDir::Object::Dist>
 
-L<< C<Test::File::ShareDir::Object::Dist>|Test::File::ShareDir::Object::Dist >> provides a simple object oriented interface for making C<TempDir> C<ShareDir>'s from a given path:
+L<< C<Test::File::ShareDir::Object::Dist>|Test::File::ShareDir::Object::Dist >> provides a simple object oriented interface for
+making C<TempDir> C<ShareDir>'s from a given path:
 
     use Test::File::ShareDir::Object::Dist;
 
@@ -128,7 +288,8 @@ See L<< C<Test::File::ShareDir::Object::Dist>|Test::File::ShareDir::Object::Dist
 
 =head3 C<Test::File::ShareDir::Object::Module>
 
-L<< C<Test::File::ShareDir::Object::Module>|Test::File::ShareDir::Object::Module >> provides a simple object oriented interface for making C<TempDir> C<ShareDir>'s from a given path:
+L<< C<Test::File::ShareDir::Object::Module>|Test::File::ShareDir::Object::Module >> provides a simple object oriented interface
+for making C<TempDir> C<ShareDir>'s from a given path:
 
     use Test::File::ShareDir::Object::Module;
 
@@ -195,11 +356,13 @@ C<-module> contains a C<hashref> mapping Module names to path names for module_d
 
   module_dir('My::Module')
 
-Notedly, it is a C<hashref>, which means there is a limitation of one share dir per module. This is simply because having more than one share dir per module makes no sense at all.
+Notedly, it is a C<hashref>, which means there is a limitation of one share dir per module. This is simply because having more
+than one share dir per module makes no sense at all.
 
 =head3 -dist
 
-C<-dist> contains a C<hashref> mapping Distribution names to path names for dist_dir style share dirs. The same limitation applied to C<-module> applies here.
+C<-dist> contains a C<hashref> mapping Distribution names to path names for dist_dir style share dirs. The same limitation
+applied to C<-module> applies here.
 
   -share => {
     -dist => { 'My-Dist' => 'share/mydist' }
@@ -213,7 +376,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
