@@ -1,23 +1,44 @@
+use 5.006;    # pragmas
 use strict;
 use warnings;
 
 package Test::File::ShareDir::Module;
-BEGIN {
-  $Test::File::ShareDir::Module::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Test::File::ShareDir::Module::VERSION = '0.4.0';
-}
+$Test::File::ShareDir::Module::VERSION = '1.000000';
+# ABSTRACT: Simplified module oriented ShareDir tester
 
-# ABSTRACT: Simplified C<module> oriented C<ShareDir> tester
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 use File::ShareDir 1.00 qw();
 
 
-sub import {
-  my ( $class, $arg ) = @_;
 
-  if ( not ref $arg or not ref $arg eq 'HASH' ) {
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+sub import {
+  my ( undef, $arg ) = @_;
+
+  if ( not ref $arg or 'HASH' ne ref $arg ) {
     require Carp;
     return Carp::croak q[Must pass a hashref];
   }
@@ -36,9 +57,9 @@ sub import {
     $params->{modules}->{$key} = $input_config{$key};
   }
 
-  my $object = Test::File::ShareDir::Object::Module->new($params);
-  $object->install_all_modules();
-  $object->add_to_inc();
+  my $module_object = Test::File::ShareDir::Object::Module->new($params);
+  $module_object->install_all_modules();
+  $module_object->add_to_inc();
 
   return 1;
 }
@@ -53,11 +74,11 @@ __END__
 
 =head1 NAME
 
-Test::File::ShareDir::Module - Simplified C<module> oriented C<ShareDir> tester
+Test::File::ShareDir::Module - Simplified module oriented ShareDir tester
 
 =head1 VERSION
 
-version 0.4.0
+version 1.000000
 
 =head1 SYNOPSIS
 
@@ -68,7 +89,8 @@ version 0.4.0
 
 C<-root> is optional, and defaults to C<cwd>
 
-B<NOTE:> There's a bug prior to 5.18 with C<use Foo { -key => }>, so for backwards compatibility, make sure you either quote the key: C<use Foo { '-key' => }>, or make it the non-first key.
+B<NOTE:> There's a bug prior to 5.18 with C<< use Foo { -key => } >>, so for backwards compatibility, make sure you either quote
+the key: C<< use Foo { '-key' => } >>, or make it the non-first key.
 
 =begin MetaPOD::JSON v1.1.0
 
@@ -86,7 +108,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
