@@ -1,15 +1,45 @@
+use 5.006;    # pragmas
 use strict;
 use warnings;
 
 package Test::File::ShareDir::Object::Inc;
-BEGIN {
-  $Test::File::ShareDir::Object::Inc::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Test::File::ShareDir::Object::Inc::VERSION = '0.4.0';
-}
+$Test::File::ShareDir::Object::Inc::VERSION = '1.000000';
+# ABSTRACT: Shared tempdir object code to inject into @INC
+
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
-# ABSTRACT: Shared C<tempdir> object code to inject into C<@INC>
 
 
 
@@ -34,6 +64,25 @@ use Class::Tiny {
   },
 };
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 sub add_to_inc {
   my ($self) = @_;
@@ -51,11 +100,11 @@ __END__
 
 =head1 NAME
 
-Test::File::ShareDir::Object::Inc - Shared C<tempdir> object code to inject into C<@INC>
+Test::File::ShareDir::Object::Inc - Shared tempdir object code to inject into @INC
 
 =head1 VERSION
 
-version 0.4.0
+version 1.000000
 
 =head1 SYNOPSIS
 
@@ -117,7 +166,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
